============
Founders & maintainers
============

* Artem Basalaev <artemDOTbasalaev@pmDOTme> (maintainer)
* Christian Darsow-Fromm <cdarsowf@physnetDOTuni-hamburg.de> (maintainer)
* Oliver Gerberding <oliver.gerberding@physikDOTuni-hamburg.de>
* Martin Hewitson <martin.hewitson@aeiDOTmpg.de>

============
Contributors
============

* Abhinav Patra <patraa1@cardiffDOTac.uk>
* Conor Mow-Lowry <c.m.mow-lowry@vuDOTnl>
* Daniel Voigt <daniel.voigt@physikDOTuni-hamburg.de>
* Jonathan Perry <j.w.perry[at]vuDOTnl>
* Nathan A. Holland <nholland@nikhefDOTnl>
* Nils Leander Weickhardt <leander.weickhardt@physikDOTuni-hamburg.de>
* Octavio Vega <vega00087@gmailDOTcom>
* Pooya Saffarieh <p.saffarieh@nikhefDOTnl>
* Saurav Bania <saurav.bania@studiumDOTuni-hamburg.de>
* Shreevathsa Chalathadka Subrahmanya <shreevathsa.chalathadka@physikDOTuni-hamburg.de>
* Tim J. Kuhlbusch <tim[dot]kuhlbusch[at]rwth-aachen.de>
